# encoding: utf-8

module AMarmita

  module Helpers

    extend self

    MONTH_NAMES_PT = ["", "janeiro", "fevereiro", "março", "abril", "maio", "junho", "julho", "agosto", "setembro", "outubro", "novembro", "dezembro"]


    def try(object, *a, &b)
      if a.empty? && block_given?
        yield object
      else
        object.respond_to?(a.first) ? object.public_send(*a, &b) : nil
      end
    end

    def to_int(string)
      string.nil? ? 0 : string.gsub(/[^0-9]/, '').to_i
    end

    def to_float(string)
      return 0 if string.nil?
      
      values = string.scan(/\d+[,.]*\d*/).flatten.map(&:to_f)

      values.length > 1 ? values : values.first
    end

    def cart_date_parser(string)
      return nil if string.nil?

      day, month = *string.scan(/.* - ([0-9]*) (.*)/).flatten

      format_date "#{Date.today.year}-#{get_month_number(month)}-#{day}"
    end

    def date_parser(date)
      if date.is_a?(String)
        date = Date.parse(date) rescue nil
      end

      date
    end

    def format_date(date)
      date = date_parser(date)

      date = (Date.today + 1) unless date.respond_to?(:strftime)

      date.strftime('%Y-%m-%d')
    end

    def get_month_number(month)
      MONTH_NAMES_PT.index(month.downcase)
    end

    def blank?(object)
      case object
      when String
        object == ''
      else
        object.nil?
      end
    end
    
  end

end
