require "a_marmita/meals/scrapper"

module AMarmita
  module Meals

    SOUP, MAIN_COURSE, DESSERT = 1, 2, 3

    class Base < ClientModule
    
      def today_menu
        page = get_page "http://www.amarmita.com/ementa.php"
        
        content_rows = page.parser.css('#conteudo > table > tr')
        
        { available_days: parse_links(page), list: parse_meals(content_rows) }
      end

      def soups(date = nil, week_number = nil)
        get_meals(SOUP, date, week_number)
      end

      def main_courses(date = nil, week_number = nil)
        get_meals(MAIN_COURSE, date, week_number)
      end

      def desserts(date = nil, week_number = nil)
        get_meals(DESSERT, date, week_number)
      end


      protected ################### PROTECTED ################

      def get_meals(type, date = nil, week_number = nil)
        date = Helpers.date_parser(date) || Date.today
        week_number ||= date.strftime('%U').to_i + 1

        page = get_page "http://www.amarmita.com/encomendamain.php?week=#{week_number}&tipo=#{type}&ano=#{date.year}&mes=#{date.month}&dia=#{date.day}"
        
        content_rows = page.parser.css('table')[0].css('> tr')

        parse_meals(content_rows)
      end

      def parse_links(page)
        page.links.inject([]) do |links, link|
          links << get_date_and_week_number_from_javascript_function(link.href) if link.href.include?('em_setday')
          links
        end
      end

      def parse_meals(content_rows)
        content_rows.map { |row| Meals::Scrapper.new(row).scrap }.compact
      end

      def get_date_and_week_number_from_javascript_function(javascript_function)
        args = javascript_function[(javascript_function.index('(') + 1)..-2].split(',')
        
        { date: args[0..2].join('-'), week_number: args[3] }
      end

    end

  end
end
